#' FAQ - Is my class compatible with vctrs?
#'
#' @includeRmd man/faq/developer/reference-compatibility.Rmd description
#'
#' @name reference-faq-compatibility
NULL

#' FAQ - How does coercion work in vctrs?
#'
#' @includeRmd man/faq/developer/theory-coercion.Rmd description
#'
#' @name theory-faq-coercion
NULL

#' FAQ - How to implement ptype2 and cast methods?
#'
#' @includeRmd man/faq/developer/howto-coercion.Rmd description
#'
#' @name howto-faq-coercion
NULL

#' FAQ - How to implement ptype2 and cast methods? (Data frames)
#'
#' @includeRmd man/faq/developer/howto-coercion-data-frame.Rmd description
#'
#' @name howto-faq-coercion-data-frame
NULL
